Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+3 -3
View File
@@ -175,9 +175,9 @@ impl Config {
FullstackHTMLTemplate::new(&cfg.unwrap())
}
pub(crate) fn create_cache(&mut self) -> dioxus_ssr::incremental::IncrementalRenderer {
let mut builder = dioxus_ssr::incremental::IncrementalRenderer::builder()
.static_dir(self.output_dir.clone());
pub(crate) fn create_cache(&mut self) -> dioxus_isrg::IncrementalRenderer {
let mut builder =
dioxus_isrg::IncrementalRenderer::builder().static_dir(self.output_dir.clone());
if let Some(map_path) = self.map_path.take() {
builder = builder.map_path(map_path);
}